@@ -55,6 +55,7 @@ __all__ = (
     "ConfigurationInfoTypeDef",
     "ConfigurationRevisionTypeDef",
     "ConfigurationTypeDef",
+    "ConnectivityInfoTypeDef",
     "CreateClusterRequestRequestTypeDef",
     "CreateClusterResponseTypeDef",
     "CreateConfigurationRequestRequestTypeDef",
@@ -111,6 +112,7 @@ __all__ = (
     "PaginatorConfigTypeDef",
     "PrometheusInfoTypeDef",
     "PrometheusTypeDef",
+    "PublicAccessTypeDef",
     "RebootBrokerRequestRequestTypeDef",
     "RebootBrokerResponseTypeDef",
     "ResponseMetadataTypeDef",
@@ -136,6 +138,8 @@ __all__ = (
     "UpdateClusterKafkaVersionResponseTypeDef",
     "UpdateConfigurationRequestRequestTypeDef",
     "UpdateConfigurationResponseTypeDef",
+    "UpdateConnectivityRequestRequestTypeDef",
+    "UpdateConnectivityResponseTypeDef",
     "UpdateMonitoringRequestRequestTypeDef",
     "UpdateMonitoringResponseTypeDef",
     "UpdateSecurityRequestRequestTypeDef",
@@ -208,6 +212,7 @@ _OptionalBrokerNodeGroupInfoTypeDef = TypedDict(
         "BrokerAZDistribution": Literal["DEFAULT"],
         "SecurityGroups": Sequence[str],
         "StorageInfo": "StorageInfoTypeDef",
+        "ConnectivityInfo": "ConnectivityInfoTypeDef",
     },
     total=False,
 )
@@ -383,6 +388,14 @@ ConfigurationTypeDef = TypedDict(
     },
 )
 
+ConnectivityInfoTypeDef = TypedDict(
+    "ConnectivityInfoTypeDef",
+    {
+        "PublicAccess": "PublicAccessTypeDef",
+    },
+    total=False,
+)
+
 _RequiredCreateClusterRequestRequestTypeDef = TypedDict(
     "_RequiredCreateClusterRequestRequestTypeDef",
     {
@@ -651,6 +664,9 @@ GetBootstrapBrokersResponseTypeDef = TypedDict(
         "BootstrapBrokerStringTls": str,
         "BootstrapBrokerStringSaslScram": str,
         "BootstrapBrokerStringSaslIam": str,
+        "BootstrapBrokerStringPublicTls": str,
+        "BootstrapBrokerStringPublicSaslScram": str,
+        "BootstrapBrokerStringPublicSaslIam": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -918,6 +934,7 @@ MutableClusterInfoTypeDef = TypedDict(
         "InstanceType": str,
         "ClientAuthentication": "ClientAuthenticationTypeDef",
         "EncryptionInfo": "EncryptionInfoTypeDef",
+        "ConnectivityInfo": "ConnectivityInfoTypeDef",
     },
     total=False,
 )
@@ -991,6 +1008,14 @@ PrometheusTypeDef = TypedDict(
     total=False,
 )
 
+PublicAccessTypeDef = TypedDict(
+    "PublicAccessTypeDef",
+    {
+        "Type": str,
+    },
+    total=False,
+)
+
 RebootBrokerRequestRequestTypeDef = TypedDict(
     "RebootBrokerRequestRequestTypeDef",
     {
@@ -1253,6 +1278,24 @@ UpdateConfigurationResponseTypeDef = TypedDict(
     },
 )
 
+UpdateConnectivityRequestRequestTypeDef = TypedDict(
+    "UpdateConnectivityRequestRequestTypeDef",
+    {
+        "ClusterArn": str,
+        "ConnectivityInfo": "ConnectivityInfoTypeDef",
+        "CurrentVersion": str,
+    },
+)
+
+UpdateConnectivityResponseTypeDef = TypedDict(
+    "UpdateConnectivityResponseTypeDef",
+    {
+        "ClusterArn": str,
+        "ClusterOperationArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredUpdateMonitoringRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateMonitoringRequestRequestTypeDef",
     {
